==> service-0.23.0-sources.jar: org/ehrbase/util/WebTemplateNodeQuery.java <==
/*
 * Copyright (c) 2022 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project EHRbase
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.util;

import org.ehrbase.aql.dto.path.AqlPath;
import org.ehrbase.webtemplate.model.WebTemplate;
import org.ehrbase.webtemplate.model.WebTemplateNode;

public class WebTemplateNodeQuery {

    private final WebTemplateNode webTemplateNode;
    private final WebTemplate webTemplate;
    private final StringBuilder pathBuilder = new StringBuilder();

    public WebTemplateNodeQuery(WebTemplate webTemplate, WebTemplateNode webTemplateNode) {
        this.webTemplate = webTemplate;
        this.webTemplateNode = webTemplateNode;
    }

    public boolean requiresNamePredicate() {
        for (AqlPath.AqlNode aqlNode : webTemplateNode.getAqlPathDto().getNodes()) {
            pathBuilder.append("/");
            pathBuilder.append(aqlNode.getName());
            pathBuilder.append("[");
            pathBuilder.append(aqlNode.getAtCode());
            pathBuilder.append("]");

            if (webTemplate.findAllByAqlPath(pathBuilder.toString(), true).size() > 1) return true;
        }
        return false;
    }
}

==> service-0.30.0-sources.jar: org/ehrbase/util/WebTemplateNodeQuery.java <==
/*
 * Copyright (c) 2022 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project EHRbase
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.util;

import org.ehrbase.openehr.sdk.aql.webtemplatepath.AqlPath;
import org.ehrbase.openehr.sdk.webtemplate.model.WebTemplate;
import org.ehrbase.openehr.sdk.webtemplate.model.WebTemplateNode;

public class WebTemplateNodeQuery {

    private final WebTemplateNode webTemplateNode;
    private final WebTemplate webTemplate;
    private final StringBuilder pathBuilder = new StringBuilder();

    public WebTemplateNodeQuery(WebTemplate webTemplate, WebTemplateNode webTemplateNode) {
        this.webTemplate = webTemplate;
        this.webTemplateNode = webTemplateNode;
    }

    public boolean requiresNamePredicate() {
        for (AqlPath.AqlNode aqlNode : webTemplateNode.getAqlPathDto().getNodes()) {
            pathBuilder.append("/");
            pathBuilder.append(aqlNode.getName());
            pathBuilder.append("[");
            pathBuilder.append(aqlNode.getAtCode());
            pathBuilder.append("]");

            if (webTemplate.findAllByAqlPath(pathBuilder.toString(), true).size() > 1) return true;
        }
        return false;
    }
}
